Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(535)

Unified Diff: ui/arc/notification/arc_notification_content_view.h

Issue 2906323002: Rename ArcCustomNotificationView to ArcNotificationContentView (Closed)
Patch Set: Addressed comments Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/arc/notification/arc_notification_content_view.h
diff --git a/ui/arc/notification/arc_custom_notification_view.h b/ui/arc/notification/arc_notification_content_view.h
similarity index 89%
rename from ui/arc/notification/arc_custom_notification_view.h
rename to ui/arc/notification/arc_notification_content_view.h
index 0257b3db82944ffb18bac1a2c5d4e6689e3b637b..d51adddffeab1d68e3afb9bad5446a9c3180ab59 100644
--- a/ui/arc/notification/arc_custom_notification_view.h
+++ b/ui/arc/notification/arc_notification_content_view.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef UI_ARC_NOTIFICATION_ARC_CUSTOM_NOTIFICATION_VIEW_H_
-#define UI_ARC_NOTIFICATION_ARC_CUSTOM_NOTIFICATION_VIEW_H_
+#ifndef UI_ARC_NOTIFICATION_ARC_NOTIFICATION_CONTENT_VIEW_H_
+#define UI_ARC_NOTIFICATION_ARC_NOTIFICATION_CONTENT_VIEW_H_
#include <memory>
#include <string>
@@ -37,10 +37,9 @@ class Widget;
namespace arc {
// ArcCustomNotificationView is a view to host NotificationSurface and show the
// content in itself. This is implemented as a child of ArcNotificationView.
-// TODO(yoshiki): Rename this class to ArcNotificationContentsView.
-class ArcCustomNotificationView
+class ArcNotificationContentView
: public views::NativeViewHost,
public views::ButtonListener,
public aura::WindowObserver,
@@ -48,8 +47,8 @@ class ArcCustomNotificationView
public ArcNotificationSurfaceManager::Observer,
public gfx::AnimationDelegate {
public:
- explicit ArcCustomNotificationView(ArcNotificationItem* item);
- ~ArcCustomNotificationView() override;
+ explicit ArcNotificationContentView(ArcNotificationItem* item);
+ ~ArcNotificationContentView() override;
std::unique_ptr<ArcNotificationContentViewDelegate>
CreateContentViewDelegate();
@@ -65,12 +64,12 @@ class ArcCustomNotificationView
// requires size of this class.
class ControlButton : public message_center::PaddedButton {
public:
- explicit ControlButton(ArcCustomNotificationView* owner);
+ explicit ControlButton(ArcNotificationContentView* owner);
void OnFocus() override;
void OnBlur() override;
private:
- ArcCustomNotificationView* const owner_;
+ ArcNotificationContentView* const owner_;
DISALLOW_COPY_AND_ASSIGN(ControlButton);
};
@@ -158,9 +157,9 @@ class ArcCustomNotificationView
base::string16 accessible_name_;
- DISALLOW_COPY_AND_ASSIGN(ArcCustomNotificationView);
+ DISALLOW_COPY_AND_ASSIGN(ArcNotificationContentView);
};
} // namespace arc
-#endif // UI_ARC_NOTIFICATION_ARC_CUSTOM_NOTIFICATION_VIEW_H_
+#endif // UI_ARC_NOTIFICATION_ARC_NOTIFICATION_CONTENT_VIEW_H_
« no previous file with comments | « ui/arc/notification/arc_custom_notification_view.cc ('k') | ui/arc/notification/arc_notification_content_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -37,10 +37,9 @@ class Widget;
namespace arc {
-// ArcCustomNotificationView is a view to host NotificationSurface and show the
+// ArcNotificationContentView is a view to host NotificationSurface and show the
// content in itself. This is implemented as a child of ArcNotificationView.
This is Rietveld 408576698